@@ -1,5 +1,6 @@
 import logging
 from datetime import timedelta
+from uuid import uuid4
 
 from django.contrib.auth import get_user_model
 from django.db import models
@@ -8,8 +9,8 @@ from django_extensions.db.models import TimeStampedModel
 from music.models import Track
 from podcasts.models import Episode
 from scrobbles.utils import check_scrobble_for_finish
-from videos.models import Video
 from sports.models import SportEvent
+from videos.models import Video
 
 logger = logging.getLogger(__name__)
 User = get_user_model()
@@ -17,6 +18,7 @@ BNULL = {"blank": True, "null": True}
 
 
 class Scrobble(TimeStampedModel):
+    uuid = models.UUIDField(editable=False, **BNULL)
     video = models.ForeignKey(Video, on_delete=models.DO_NOTHING, **BNULL)
     track = models.ForeignKey(Track, on_delete=models.DO_NOTHING, **BNULL)
     podcast_episode = models.ForeignKey(
@@ -38,6 +40,22 @@ class Scrobble(TimeStampedModel):
     in_progress = models.BooleanField(default=True)
     scrobble_log = models.TextField(**BNULL)
 
+    def save(self, *args, **kwargs):
+        if not self.uuid:
+            self.uuid = uuid4()
+
+        return super(Scrobble, self).save(*args, **kwargs)
+
+    @property
+    def status(self) -> str:
+        if self.is_paused:
+            return 'paused'
+        if self.played_to_completion:
+            return 'finished'
+        if self.in_progress:
+            return 'in-progress'
+        return 'zombie'
+
     @property
     def percent_played(self) -> int:
         if not self.media_obj.run_time_ticks:
@@ -83,12 +101,11 @@ class Scrobble(TimeStampedModel):
             cls.objects.filter(
                 video=video,
                 user_id=user_id,
-                played_to_completion=False,
             )
             .order_by('-modified')
             .first()
         )
-        if scrobble:
+        if scrobble and scrobble.playback_perecnt <= 100:
             logger.info(
                 f"Found existing scrobble for video {video}, updating",
                 {"scrobble_data": scrobble_data},
@@ -133,7 +150,8 @@ class Scrobble(TimeStampedModel):
             {"scrobble_data": scrobble_data},
         )
         # If creating a new scrobble, we don't need status
-        scrobble_data.pop('mopidy_status')
+        scrobble_data.pop('mopidy_status', None)
+        scrobble_data.pop('jellyfin_status', None)
         return cls.create(scrobble_data)
 
     @classmethod
@@ -231,13 +249,13 @@ class Scrobble(TimeStampedModel):
         )
         return scrobble
 
-    def stop(self) -> None:
+    def stop(self, force_finish=False) -> None:
         if not self.in_progress:
             logger.warning("Scrobble already stopped")
             return
         self.in_progress = False
         self.save(update_fields=['in_progress'])
-        check_scrobble_for_finish(self)
+        check_scrobble_for_finish(self, force_finish)
 
     def pause(self) -> None:
         if self.is_paused:
@@ -253,6 +271,10 @@ class Scrobble(TimeStampedModel):
             self.in_progress = True
             return self.save(update_fields=["is_paused", "in_progress"])
 
+    def cancel(self) -> None:
+        check_scrobble_for_finish(self, force_finish=True)
+        self.delete()
+
     def update_ticks(self, data) -> None:
         self.playback_position_ticks = data.get("playback_position_ticks")
         self.playback_position = data.get("playback_position")
